@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2006 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,11 +23,13 @@ import os
 import time
 import urlparse
 import urllib
+import urllib2
 
 import urlbase
 import linkcheck
 import linkcheck.log
 import linkcheck.checker
+import linkcheck.fileutil
 
 # if file extension lookup was unsuccessful, look at the content
 contents = {
@@ -83,7 +85,7 @@ class FileUrl (urlbase.UrlBase):
     """
 
     def init (self, base_ref, base_url, parent_url, recursion_level,
-              consumer, line, column, name):
+              aggregate, line, column, name):
         """
         Besides the usual initialization the URL is normed according
         to the platform:
@@ -91,7 +93,7 @@ class FileUrl (urlbase.UrlBase):
          - under Windows platform the drive specifier is normed
         """
         super(FileUrl, self).init(base_ref, base_url, parent_url,
-                               recursion_level, consumer, line, column, name)
+                               recursion_level, aggregate, line, column, name)
         if self.base_url is None:
             return
         base_url = self.base_url
@@ -105,7 +107,7 @@ class FileUrl (urlbase.UrlBase):
         base_url = re.sub("^file://(/?)([a-zA-Z]):", r"file:///\2|", base_url)
         # norm base url again after changing
         if self.base_url != base_url:
-            base_url, is_idn = linkcheck.url.url_norm(base_url)
+            base_url, is_idn = linkcheck.checker.urlbase.url_norm(base_url)
             self.base_url = unicode(base_url)
 
     def build_url (self):
@@ -129,7 +131,8 @@ class FileUrl (urlbase.UrlBase):
         if self.is_directory():
             self.set_result(_("directory"))
         else:
-            super(FileUrl, self).check_connection()
+            url = linkcheck.fileutil.pathencode(self.url)
+            self.url_connection = urllib2.urlopen(url)
             self.check_case_sensitivity()
 
     def check_case_sensitivity (self):
@@ -143,11 +146,10 @@ class FileUrl (urlbase.UrlBase):
         path = self.get_os_filename()
         realpath = get_nt_filename(path)
         if path != realpath:
-            self.add_warning(_("The URL path %r is not the same as the " \
-                               "system path %r. You should always use " \
+            self.add_warning(_("The URL path %r is not the same as the "
+                               "system path %r. You should always use "
                                "the system path in URLs.") % (path, realpath),
                                tag="file-system-path")
-        pass
 
     def get_content (self):
         """
@@ -208,7 +210,7 @@ class FileUrl (urlbase.UrlBase):
         path = self.urlparts[2]
         if os.name == 'nt':
             path = prepare_urlpath_for_nt(path)
-        return urllib.url2pathname(path)
+        return linkcheck.fileutil.pathencode(urllib.url2pathname(path))
 
     def is_directory (self):
         """
@@ -230,12 +232,12 @@ class FileUrl (urlbase.UrlBase):
         if self.is_directory():
             return True
         # guess by extension
-        for ro in linkcheck.checker.extensions.values():
+        for ro in linkcheck.checker.extensions.itervalues():
             if ro.search(self.url):
                 return True
         # try to read content (can fail, so catch error)
         try:
-            for ro in contents.values():
+            for ro in contents.itervalues():
                 if ro.search(self.get_content()[:30]):
                     return True
         except IOError:
@@ -249,11 +251,11 @@ class FileUrl (urlbase.UrlBase):
         if self.is_directory():
             self.parse_html()
             return
-        for key, ro in linkcheck.checker.extensions.items():
+        for key, ro in linkcheck.checker.extensions.iteritems():
             if ro.search(self.url):
                 getattr(self, "parse_"+key)()
                 return
-        for key, ro in contents.items():
+        for key, ro in contents.iteritems():
             if ro.search(self.get_content()[:30]):
                 getattr(self, "parse_"+key)()
                 return
