@@ -106,10 +106,10 @@ class UrlBase (object):
         self.name = name
         if self.base_ref:
             assert not linkcheck.url.url_needs_quoting(self.base_ref), \
-                   "unquoted %r" % self.base_ref
+                   "unquoted base reference URL %r" % self.base_ref
         if self.parent_url:
             assert not linkcheck.url.url_needs_quoting(self.parent_url), \
-                   "unquoted %r" % self.parent_url
+                   "unquoted parent URL %r" % self.parent_url
         url = linkcheck.checker.absolute_url(base_url, base_ref, parent_url)
         # assume file link if no scheme is found
         self.scheme = url.split(":", 1)[0] or "file"
@@ -373,10 +373,6 @@ class UrlBase (object):
                 raise KeyboardInterrupt(value)
             else:
                 raise
-        except KeyboardInterrupt:
-            raise
-        except:
-            linkcheck.director.console.internal_error()
 
     def add_country_info (self):
         """
@@ -666,6 +662,7 @@ class UrlBase (object):
                 base_ref = codebase
             else:
                 base_ref = h.base_ref
+            base_ref = linkcheck.url.url_norm(base_ref)[0]
             url_data = linkcheck.checker.get_url_from(url,
                   self.recursion_level+1, self.aggregate, parent_url=self.url,
                   base_ref=base_ref, line=line, column=column, name=name,
