@@ -15,8 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 import time
-import Queue
 import task
+import linkcheck.cache.urlqueue
 
 
 def check_url (urlqueue, logger):
@@ -54,20 +54,19 @@ class Checker (task.CheckedTask):
         while True:
             self.check_url()
             if self.stopped():
-                return
+                break
 
     def check_url (self):
         """
         Try to get URL data from queue and check it.
         """
         try:
-            url_data = self.urlqueue.get(timeout=1)
-        except Queue.Empty:
-            time.sleep(1)
-            return
-        if url_data is not None:
-            self.check_url_data(url_data)
-            self.setName(self.origname)
+            url_data = self.urlqueue.get(timeout=0.1)
+            if url_data is not None:
+                self.check_url_data(url_data)
+                self.setName(self.origname)
+        except linkcheck.cache.urlqueue.Empty:
+            time.sleep(0.1)
 
     def check_url_data (self, url_data):
         """
