@@ -18,11 +18,10 @@
 A GraphXML logger.
 """
 
-import linkcheck.logger.xmllog
-import linkcheck.configuration
+import xmllog
 
 
-class GraphXMLLogger (linkcheck.logger.xmllog.XMLLogger):
+class GraphXMLLogger (xmllog.XMLLogger):
     """
     XML output mirroring the GML structure. Easy to parse with any XML
     tool.
@@ -50,8 +49,6 @@ class GraphXMLLogger (linkcheck.logger.xmllog.XMLLogger):
         """
         Write one node and all possible edges.
         """
-        if self.fd is None:
-            return
         node = url_data
         if node.url and not self.nodes.has_key(node.url):
             node.id = self.nodeid
@@ -99,8 +96,6 @@ class GraphXMLLogger (linkcheck.logger.xmllog.XMLLogger):
         """
         Finish graph output, and print end of checking info as xml comment.
         """
-        if self.fd is None:
-            return
         self.xml_endtag(u"graph")
         self.xml_endtag(u"GraphXML")
         self.xml_end_output()
