@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2006 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +14,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+#
+# Some functions have been taken and adjusted from the quodlibet
+# source. Quodlibet is (C) 2004-2005 Joe Wreschnig, Michael Urman
+# and licensed under the GNU General Public License version 2.
 """
 Various string utility functions. Note that these functions are not
 necessarily optimised for large strings, so use with care.
@@ -21,7 +25,9 @@ necessarily optimised for large strings, so use with care.
 
 import re
 import textwrap
+import codecs
 import os
+import math
 import time
 import urlparse
 import pydoc
@@ -52,10 +58,10 @@ def ascii_safe (s):
 
     @param s: the Unicode string to be encoded
     @type s: unicode or None
-    @return: encoded ASCII version of s, or s itself if s evaluated to False
+    @return: encoded ASCII version of s, or None if s was None
     @rtype: string
     """
-    if s:
+    if isinstance(s, unicode):
         s = s.encode('ascii', 'ignore')
     return s
 
@@ -71,6 +77,16 @@ def is_ascii (s):
         return False
 
 
+def is_encoding (text):
+    """
+    Check if string is a valid encoding.
+    """
+    try:
+        return codecs.lookup(text)
+    except (LookupError, ValueError):
+        return False
+
+
 def url_unicode_split (url):
     """
     Like urlparse.urlsplit(), but always returning unicode parts.
@@ -143,13 +159,13 @@ def indent (text, indent_string="  "):
 
 
 def get_line_number (s, index):
-    """
-    Return the line number of s[index]. Lines are assumed to be separated
-    by the ASCII character '\\n'.
+    r"""
+    Return the line number of s[index] or zero on errors.
+    Lines are assumed to be separated by the ASCII character '\n'.
     """
     i = 0
     if index < 0:
-        index = 0
+        return 0
     line = 1
     while i < index:
         if s[i] == '\n':
@@ -184,19 +200,20 @@ def strsize (b):
     raises a value error.
     """
     if b < 0:
-        raise ValueError, "Invalid negative byte number"
-    if b == 1:
-        return u"%d Byte" % b
+        raise ValueError("Invalid negative byte number")
     if b < 1024:
-        return u"%d Bytes" % b
-    b /= 1024.0
-    if b < 1024:
-        return u"%.2f kB" % b
-    b /= 1024.0
-    if b < 1024:
-        return u"%.2f MB" % b
-    b /= 1024.0
-    return u"%.2f GB"
+        return u"%dB" % b
+    if b < 1024 * 10:
+        return u"%dKB" % int(b / 1024)
+    if b < 1024 * 1024:
+        return u"%.2fKB" % (float(b) / 1024)
+    if b < 1024 * 1024 * 10:
+        return u"%.2fMB" % (float(b) / (1024*1024))
+    if b < 1024 * 1024 * 1024:
+        return u"%.1fMB" % (float(b) / (1024*1024))
+    if b < 1024 * 1024 * 1024 * 10:
+        return u"%.2fGB" % (float(b) / (1024*1024*1024))
+    return u"%.1fGB" % (float(b) / (1024*1024*1024))
 
 
 def strtime (t):
@@ -207,18 +224,61 @@ def strtime (t):
            strtimezone()
 
 
+# from quodlibet
 def strduration (duration):
-    """
-    Return translated and formatted time duration.
-    """
-    name = _("seconds")
-    if duration > 60:
-        duration = duration / 60
-        name = _("minutes")
-    if duration > 60:
-        duration = duration / 60
-        name = _("hours")
-    return u" %.3f %s" % (duration, name)
+    """Turn a time value in seconds into hh:mm:ss or mm:ss."""
+    if duration < 0:
+        duration = abs(duration)
+        prefix = "-"
+    else:
+        prefix = ""
+    duration = math.ceil(duration)
+    if duration >= 3600: # 1 hour
+        # time, in hours:minutes:seconds
+        return "%s%02d:%02d:%02d" % (prefix, duration // 3600,
+                                   (duration % 3600) // 60, duration % 60)
+    else:
+        # time, in minutes:seconds
+        return "%s%02d:%02d" % (prefix, duration // 60, duration % 60)
+
+
+# from quodlibet
+def strduration_long (duration):
+    """Turn a time value in seconds into x hours, x minutes, etc."""
+    if duration < 0:
+        duration = abs(duration)
+        prefix = "-"
+    else:
+        prefix = ""
+    if duration < 1:
+        return _("%s%.02f seconds") % (prefix, duration)
+    # translation dummies
+    _n("%d second", "%d seconds", 1)
+    _n("%d minute", "%d minutes", 1)
+    _n("%d hour", "%d hours", 1)
+    _n("%d day", "%d days", 1)
+    _n("%d year", "%d years", 1)
+    cutoffs = [
+        (60, "%d second", "%d seconds"),
+        (60, "%d minute", "%d minutes"),
+        (24, "%d hour", "%d hours"),
+        (365, "%d day", "%d days"),
+        (None, "%d year", "%d years"),
+    ]
+    time_str = []
+    for divisor, single, plural in cutoffs:
+        if duration < 1:
+            break
+        if divisor is None:
+            duration, unit = 0, duration
+        else:
+            duration, unit = divmod(duration, divisor)
+        if unit:
+            time_str.append(_n(single, plural, unit) % unit)
+    time_str.reverse()
+    if len(time_str) > 2:
+        time_str.pop()
+    return "%s%s" % (prefix, ", ".join(time_str))
 
 
 def strtimezone ():
